@@ -28,21 +28,39 @@ env = dotenv_values(env_path)
 
 # Seems to have problem with dotenv with pyto on IOS 15
 try:
-    BASEDIR = Path(env["blog_path"])
-    vault = Path(env["vault"])
+    BASEDIR = Path(env["blog_path"]).expanduser()
+    vault = Path(env["vault"]).expanduser()
     web = env["blog"]
 except KeyError:
     with open(env_path) as f:
-        vault = "".join(f.readlines(1)).replace("vault=", "")
-        BASEDIR = "".join(f.readlines(2)).replace("blog_path=", "")
+        vault_str = "".join(f.readlines(1)).replace("vault=", "")
+        basedir_str = "".join(f.readlines(2)).replace("blog_path=", "")
+
+        vault = Path(vault_str)
+        BASEDIR = Path(basedir_str)
         web = "".join(f.readlines(3)).replace("blog=", "")
-    if len(vault) == 0 or len(web) == 0 or len(web) == 0:
-        print("Please provide the good path for all folder")
+    if len(vault_str) == 0 or len(basedir_str) == 0 or len(web) == 0:
+        print("Please provide a valid path for all config items")
         exit(1)
+except RuntimeError:
+    BASEDIR = Path(env["blog_path"])
+    vault = Path(env["vault"])
+    web = env["blog"]
+
+try:
+    vault = vault.expanduser()
+    BASEDIR = BASEDIR.expanduser()
+except RuntimeError:
+    print("Please, provid a valid path for all config item.")
+    exit(1)
+
 path = Path(f"{BASEDIR}/.git")  # GIT SHARED
 post = Path(f"{BASEDIR}/_notes")
 img = Path(f"{BASEDIR}/assets/img/")
 
+# The img/ directory may not exist yet if starting from scratch or from one that has not had images yet
+img.mkdir(exist_ok=True)
+
 
 def git_push(COMMIT):
     try:
